import instance from '@/tool/axios'

import type { UserData } from '@/types/User'
import type { Pages, AsProp, Role } from '@/types/Tool'
import type { IAsSpace } from '@/types/AsSpace'
import type { ISourceMaterialProps } from '@/types/SourceMaterial'
import type { CatalogTreeOri } from '@/types/Catalog'
import type { Advertiser } from '@/types/Advertiser'
import type { OriginalityItem } from '@/types/AdListPage'

/**
 * 获取验证码
 */
export const getCaptcha = (phone: string) => instance.post('/ad/users/sendCond', { phone })

/**
 * 登录
 */
export const login = (data: UserData) => instance.post('/ad/users/login', data)

/**
 * 获取站点列表
 */
export const getSiteList = () => instance.get('/ad/media/list')

/**
 * 获取创意列表
 */
export const getOriginalityList = (data: Pages) => instance.post('/ad/creatives/list', data)

/**
 * 创意发布
 */
export const onlineOriginality = (id: number) =>
  instance.get(`/ad/creatives/publish?creativeId=${id}`)

/**
 * 获取创意详情
 */
export const getOriginalityDetail = (id: number) => instance.get(`/ad/creatives/info/${id}`)

/**
 * 删除创意
 */
export const deleteOriginality = (id: number) => instance.post(`/ad/creatives/delete/${id}`)

/**
 * 创建创意
 */
export const createOriginality = (data: OriginalityItem) =>
  instance.post('/ad/creatives/create', data)

/**
 * 修改创意
 */
export const updateOriginality = (data: OriginalityItem) =>
  instance.post('/ad/creatives/update', data)

/**
 * 修改广告创意状态
 */
export const updateOriginalityStatus = (data: { id: number; status: number }) =>
  instance.post('/ad/creatives/updateStatus', data)

/**
 * 获取可选广告位列表
 */
export const getAsList = (data: AsProp) => instance.post('/ad/slots/selectable', data)

/**
 * 获取广告位列表
 */
export const getAsSpaceList = (data: Pages) => instance.post('/ad/slots/list', data)

/**
 * 创建广告位列表
 */
export const createAsSpace = (data: IAsSpace) => instance.post('/ad/slots/create', data)

/**
 * 删除广告位
 */
export const deleteAsSpace = (id: number) => instance.delete(`/ad/slots/delete/${id}`)

/**
 * 修改广告位
 */
export const updateAsSpace = (data: IAsSpace) => instance.put('/ad/slots/update', data)

/**
 * 获取栏目树
 */
export const getAsTree = (media: number) => instance.get('/ad/catalog/tree?mediaId=' + media)

/**
 * 删除栏目
 */
export const deleteAsTree = (id: number) => instance.delete(`/ad/catalog/delete/${id}`)

/**
 * 修改栏目
 */
export const updateAsTree = (data: CatalogTreeOri) => instance.put('/ad/catalog/update', data)

/**
 * 创建栏目
 */
export const createAsTree = (data: CatalogTreeOri) => instance.post('/ad/catalog/create', data)

/**
 * 栏目发布
 */
export const publishAsTree = (id: number) => instance.get('/ad/catalog/publish?catalogId=' + id)

/**
 * 获取素材列表
 */
export const getMaterialList = (data: Pages) => instance.post('/ad/stuffs/list', data)

/**
 * 获取素材详情
 */
export const getMaterialDetail = (id: number) => instance.get(`/ad/stuffs/info/${id}`)

/**
 * 创建素材
 */
export const createMaterial = (data: ISourceMaterialProps) =>
  instance.post('/ad/stuffs/create', data)

/**
 * 删除素材
 */
export const deleteMaterial = (id: number) => instance.delete(`/ad/stuffs/delete/${id}`)

/**
 * 上传素材
 */
export const uploadMaterial = (data: FormData) =>
  instance.post('/ad/stuffs/upload', data, {
    headers: {
      'Content-Type': 'multipart/form-data', // 用于文件上传
    },
  })

/**
 * 修改素材
 */
export const updateMaterial = (data: ISourceMaterialProps) =>
  instance.put('/ad/stuffs/update', data)

/**
 * 素材启用禁用
 */
export const updateMaterialStatus = (data: { id: number; status: number }) =>
  instance.post('/ad/stuffs/updateStatus', data)

/**
 * 广告主列表
 */
export const getAdvertiserList = (data: Pages) => instance.post('/ad/advertiser/list', data)

/**
 * 广告主创建
 */
export const createAdvertiser = (data: Advertiser) => instance.post('/ad/advertiser/create', data)

/**
 * 广告主更新
 */
export const updateAdvertiser = (data: Advertiser) => instance.post('/ad/advertiser/update', data)

/**
 * 广告主删除
 */
export const deleteAdvertiser = (advertiserId: number) =>
  instance.post(`/ad/advertiser/delete/${advertiserId}`)

/**
 * 广告主启禁用
 */
export const updateAdvertiserStatus = (data: { id: number; status: number }) =>
  instance.post('/ad/advertiser/updateStatus', data)

/**
 * 广告主日报表
 */
export const getAdvertiserReport = (data: Pages) => instance.post('/ad/report/adv-day', data)

/**
 * 广告主月报表
 */
export const getAdvertiserMonthReport = (data: Pages) => instance.post('/ad/report/adv-month', data)

/**
 * 媒体日报表
 */
export const getMediaReport = (data: Pages) => instance.post('/ad/report/media-day', data)

/**
 * 媒体月报表
 */
export const getMediaMonthReport = (data: Pages) => instance.post('/ad/report/media-month', data)

/**
 * 省市
 */
export const getProvinceCity = () => instance.get('http://cxzx.smcic.net/ad/config/cn.json')

/**
 * 用户详情
 */
export const getUserDetail = () => instance.get('/ad/users/info')

/**
 * 批量给创意添加素材
 */
export const addMaterial = (data: { creativeId: number; stuffIds: number[] }) =>
  instance.post('/ad/stuffs/copy', data)

/**
 * 获取用户列表
 */
export const getUserList = (data: Pages) => instance.post('/ad/users/list', data)

/**
 * 创建用户
 */
export const createUser = (data: UserData) => instance.post('/ad/users/create', data)

/**
 * 修改用户
 */
export const updateUser = (data: UserData) => instance.post('/ad/users/update', data)

/**
 * 删除用户
 */
export const deleteUser = (id: number) => instance.post(`/ad/users/delete/${id}`)

/**
 * 获取角色列表
 */
export const getRole = () => instance.get('/ad/roles/list')

/**
 * 创建角色
 */
export const createRole = (data: Role) => instance.post('/ad/roles/create', data)

/**
 * 修改角色
 */
export const updateRole = (data: Role) => instance.post('/ad/roles/update', data)

/**
 * 删除角色
 */
export const deleteRole = (id: number) => instance.post(`/ad/roles/delete/${id}`)
